==> zio-aws-apigateway_2.13-5.17.157.2-sources.jar: zio/aws/apigateway/model/TestInvokeAuthorizerResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.apigateway.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class TestInvokeAuthorizerResponse(
    clientStatus: Option[Integer] = None,
    log: Option[String] = None,
    latency: Option[Long] = None,
    principalId: Option[String] = None,
    policy: Option[String] = None,
    authorization: Option[Map[String, Iterable[String]]] = None,
    claims: Option[Map[String, String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse = {
    import TestInvokeAuthorizerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
      .builder()
      .optionallyWith(clientStatus.map(value => value: java.lang.Integer))(
        _.clientStatus
      )
      .optionallyWith(log.map(value => value: java.lang.String))(_.log)
      .optionallyWith(latency.map(value => value: java.lang.Long))(_.latency)
      .optionallyWith(principalId.map(value => value: java.lang.String))(
        _.principalId
      )
      .optionallyWith(policy.map(value => value: java.lang.String))(_.policy)
      .optionallyWith(
        authorization.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.map { item =>
                item: java.lang.String
              }.asJavaCollection
            })
            .asJava
        )
      )(_.authorization)
      .optionallyWith(
        claims.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.claims)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.TestInvokeAuthorizerResponse.ReadOnly =
    zio.aws.apigateway.model.TestInvokeAuthorizerResponse.wrap(buildAwsValue())
}
object TestInvokeAuthorizerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.TestInvokeAuthorizerResponse =
      zio.aws.apigateway.model.TestInvokeAuthorizerResponse(
        clientStatus.map(value => value),
        log.map(value => value),
        latency.map(value => value),
        principalId.map(value => value),
        policy.map(value => value),
        authorization.map(value => value),
        claims.map(value => value)
      )
    def clientStatus: Option[Integer]
    def log: Option[String]
    def latency: Option[Long]
    def principalId: Option[String]
    def policy: Option[String]
    def authorization: Option[Map[String, List[String]]]
    def claims: Option[Map[String, String]]
    def getClientStatus: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("clientStatus", clientStatus)
    def getLog: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("log", log)
    def getLatency: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("latency", latency)
    def getPrincipalId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("principalId", principalId)
    def getPolicy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("policy", policy)
    def getAuthorization: ZIO[Any, AwsError, Map[String, List[String]]] =
      AwsError.unwrapOptionField("authorization", authorization)
    def getClaims: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("claims", claims)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
  ) extends zio.aws.apigateway.model.TestInvokeAuthorizerResponse.ReadOnly {
    override val clientStatus: Option[Integer] =
      scala.Option(impl.clientStatus()).map(value => value: Integer)
    override val log: Option[String] =
      scala.Option(impl.log()).map(value => value: String)
    override val latency: Option[Long] =
      scala.Option(impl.latency()).map(value => value: Long)
    override val principalId: Option[String] =
      scala.Option(impl.principalId()).map(value => value: String)
    override val policy: Option[String] =
      scala.Option(impl.policy()).map(value => value: String)
    override val authorization: Option[Map[String, List[String]]] = scala
      .Option(impl.authorization())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> value.asScala.map { item =>
              item: String
            }.toList
          })
          .toMap
      )
    override val claims: Option[Map[String, String]] = scala
      .Option(impl.claims())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
  ): zio.aws.apigateway.model.TestInvokeAuthorizerResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigateway_3-5.17.126.2-sources.jar: zio/aws/apigateway/model/TestInvokeAuthorizerResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.apigateway.model.primitives.Integer
import scala.jdk.CollectionConverters.*
final case class TestInvokeAuthorizerResponse(
    clientStatus: Option[Integer] = None,
    log: Option[String] = None,
    latency: Option[Long] = None,
    principalId: Option[String] = None,
    policy: Option[String] = None,
    authorization: Option[Map[String, Iterable[String]]] = None,
    claims: Option[Map[String, String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse = {
    import TestInvokeAuthorizerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
      .builder()
      .optionallyWith(
        clientStatus.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.clientStatus)
      .optionallyWith(log.map(value => value: java.lang.String))(_.log)
      .optionallyWith(latency.map(value => value: java.lang.Long))(_.latency)
      .optionallyWith(principalId.map(value => value: java.lang.String))(
        _.principalId
      )
      .optionallyWith(policy.map(value => value: java.lang.String))(_.policy)
      .optionallyWith(
        authorization.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.map { item =>
                item: java.lang.String
              }.asJavaCollection
            })
            .asJava
        )
      )(_.authorization)
      .optionallyWith(
        claims.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.claims)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.TestInvokeAuthorizerResponse.ReadOnly =
    zio.aws.apigateway.model.TestInvokeAuthorizerResponse.wrap(buildAwsValue())
}
object TestInvokeAuthorizerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.TestInvokeAuthorizerResponse =
      zio.aws.apigateway.model.TestInvokeAuthorizerResponse(
        clientStatus.map(value => value),
        log.map(value => value),
        latency.map(value => value),
        principalId.map(value => value),
        policy.map(value => value),
        authorization.map(value => value),
        claims.map(value => value)
      )
    def clientStatus: Option[Integer]
    def log: Option[String]
    def latency: Option[Long]
    def principalId: Option[String]
    def policy: Option[String]
    def authorization: Option[Map[String, List[String]]]
    def claims: Option[Map[String, String]]
    def getClientStatus: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("clientStatus", clientStatus)
    def getLog: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("log", log)
    def getLatency: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("latency", latency)
    def getPrincipalId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("principalId", principalId)
    def getPolicy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("policy", policy)
    def getAuthorization: ZIO[Any, AwsError, Map[String, List[String]]] =
      AwsError.unwrapOptionField("authorization", authorization)
    def getClaims: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("claims", claims)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
  ) extends zio.aws.apigateway.model.TestInvokeAuthorizerResponse.ReadOnly {
    override val clientStatus: Option[Integer] = scala
      .Option(impl.clientStatus())
      .map(value => zio.aws.apigateway.model.primitives.Integer(value))
    override val log: Option[String] =
      scala.Option(impl.log()).map(value => value: String)
    override val latency: Option[Long] =
      scala.Option(impl.latency()).map(value => value: Long)
    override val principalId: Option[String] =
      scala.Option(impl.principalId()).map(value => value: String)
    override val policy: Option[String] =
      scala.Option(impl.policy()).map(value => value: String)
    override val authorization: Option[Map[String, List[String]]] = scala
      .Option(impl.authorization())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> value.asScala.map { item =>
              item: String
            }.toList
          })
          .toMap
      )
    override val claims: Option[Map[String, String]] = scala
      .Option(impl.claims())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.TestInvokeAuthorizerResponse
  ): zio.aws.apigateway.model.TestInvokeAuthorizerResponse.ReadOnly =
    new Wrapper(impl)
}
